datacyclist
===========


A Package to analyze cycling ride's data

=======

User installation
~~~~~~~~~~~~~~~~~

If you already have a working installation of pandas and sklearn,
the easiest way to install scikit-learn is using ``pip``   ::

    pip install -U datacyclist
    
Important links
~~~~~~~~~~~~~~~
